@@ -19,8 +19,13 @@
 #include <kglobal.h>
 #include "fountain.h"
 #include "fountain.moc"
+#ifdef Q_WS_MACX
+#include <OpenGL/gl.h>
+#include <OpenGL/glu.h>
+#else
 #include <GL/glu.h>
 #include <GL/gl.h>
+#endif
 #include <qimage.h>
 #include <kdebug.h>
 #include <qpainter.h>
@@ -32,16 +37,16 @@
 // libkscreensaver interface
 extern "C"
 {
-	const char *kss_applicationName = "kfountain.kss";
-	const char *kss_description = I18N_NOOP( "Particle Fountain Screen Saver" );
-	const char *kss_version = "2.2.0";
+	KDE_EXPORT const char *kss_applicationName = "kfountain.kss";
+	KDE_EXPORT const char *kss_description = I18N_NOOP( "Particle Fountain Screen Saver" );
+	KDE_EXPORT const char *kss_version = "2.2.0";
 
-	KScreenSaver *kss_create( WId id )
+	KDE_EXPORT KScreenSaver *kss_create( WId id )
 	{
 		return new KFountainSaver( id );
 	}
 
-	QDialog *kss_setup()
+	KDE_EXPORT QDialog *kss_setup()
 	{
 		return new KFountainSetup();
 	}
