@@ -888,7 +888,7 @@ void kSlideShowSaver::traverseDirectory(const QString &dirName)
      {
         if (!fi->isDir())
         {
-           mFileList.append(fi->filePath().data());
+           mFileList.append(fi->filePath());
         }
      }
   ++it;
