@@ -7,7 +7,7 @@
  * 31-Aug-90: Adapted from xswarm by Jeff Butterworth. (butterwo@ncsc.org)
  */
 
-/* Ported to kscreensave:
+/* Ported to kscreensaver:
    July 1997, Emanuel Pirker <epirker@edu.uni-klu.ac.at>
    Contact me in case of problems, not the original author!
    Last revised: 10-Jul-97
@@ -27,6 +27,8 @@
 #include <krandomsequence.h>
 #include "xlock.h"
 
+#undef index
+
 #define TIMES	4		/* number of time positions recorded */
 #define BEEACC	2		/* acceleration of bees */
 #define WASPACC 5		/* maximum acceleration of wasp */
@@ -215,13 +217,11 @@ drawswarm(Window win, KRandomSequence &rnd)
 
 //-----------------------------------------------------------------------------
 
-#include <qpushbutton.h>
 #include <qcheckbox.h>
 #include <qlabel.h>
 #include <qcolor.h>
 #include <qlayout.h>
 
-#include <kbuttonbox.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 
@@ -314,71 +314,51 @@ void kSwarmSaver::slotTimeout()
 //-----------------------------------------------------------------------------
 
 kSwarmSetup::kSwarmSetup( QWidget *parent, const char *name )
-	: QDialog( parent, name, TRUE )
+	: KDialogBase( parent, name, true, i18n( "Setup Swarm Screen Saver" ),
+	  Ok|Cancel|Help, Ok, true )
 {
 	readSettings();
 
-	setCaption( i18n("Setup Swarm Screen Saver") );
+	setButtonText( Help, i18n( "A&bout" ) );
+	QWidget *main = makeMainWidget();
 
-	QLabel *label;
-	QPushButton *button;
-	QSlider *slider;
+	QHBoxLayout *top = new QHBoxLayout( main, 0, spacingHint() );
+	QVBoxLayout *left = new QVBoxLayout(top, spacingHint());
 
-	QVBoxLayout *tl = new QVBoxLayout(this, 10, 10);
-	QHBoxLayout *tl1 = new QHBoxLayout;
-	tl->addLayout(tl1);
-	QVBoxLayout *tl11 = new QVBoxLayout(5);
-	tl1->addLayout(tl11);
-
-	label = new QLabel( i18n("Speed:"), this );
+	QLabel *label = new QLabel( i18n("Speed:"), main );
 	min_size(label);
-	tl11->addWidget(label);
+	left->addWidget(label);
 
-	slider = new QSlider(MINSPEED, MAXSPEED, 10, speed, QSlider::Horizontal,
-                        this );
-	slider->setMinimumSize( 90, 20 );
+	QSlider *slider = new QSlider(MINSPEED, MAXSPEED, 10, speed,
+			Horizontal, main );
+	slider->setMinimumSize( 120, 20 );
     slider->setTickmarks(QSlider::Below);
     slider->setTickInterval(10);
 	connect( slider, SIGNAL( valueChanged( int ) ),
 		 SLOT( slotSpeed( int ) ) );
-	tl11->addWidget(slider);
-	tl11->addSpacing(5);
+	left->addWidget(slider);
 
-	label = new QLabel( i18n("Number of bees:"), this );
+	label = new QLabel( i18n("Number of bees:"), main );
 	min_size(label);
-	tl11->addWidget(label);
+	left->addWidget(label);
 
-	slider = new QSlider(MINBATCH, MAXBATCH, 20, maxLevels,
-                        QSlider::Horizontal, this );
-	slider->setMinimumSize( 90, 20 );
+	slider = new QSlider(MINBATCH, MAXBATCH, 20, maxLevels, Horizontal, main );
+	slider->setMinimumSize( 120, 20 );
     slider->setTickmarks(QSlider::Below);
     slider->setTickInterval(20);
 	connect( slider, SIGNAL( valueChanged( int ) ),
 		 SLOT( slotLevels( int ) ) );
-	tl11->addWidget(slider);
-	tl11->addStretch(1);
+	left->addWidget(slider);
+	left->addStretch();
 
-	preview = new QWidget( this );
+	preview = new QWidget( main );
 	preview->setFixedSize( 220, 170 );
 	preview->setBackgroundColor( black );
 	preview->show();    // otherwise saver does not get correct size
 	saver = new kSwarmSaver( preview->winId() );
-	tl1->addWidget(preview);
+	top->addWidget(preview);
 
-	KButtonBox *bbox = new KButtonBox(this);
-	button = bbox->addButton( i18n("&About"));
-	connect( button, SIGNAL( clicked() ), SLOT(slotAbout() ) );
-	bbox->addStretch(1);
-
-	button = bbox->addButton( i18n("&OK"));
-	connect( button, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
-
-	button = bbox->addButton(i18n("&Cancel"));
-	connect( button, SIGNAL( clicked() ), SLOT( reject() ) );
-	bbox->layout();
-	tl->addWidget(bbox);
-
-	tl->freeze();
+	top->addStretch();
 }
 
 void kSwarmSetup::readSettings()
@@ -413,7 +393,7 @@ void kSwarmSetup::slotLevels( int num )
 		saver->setLevels( maxLevels );
 }
 
-void kSwarmSetup::slotOkPressed()
+void kSwarmSetup::slotOk()
 {
 	KConfig *config = klock_config();
 	config->setGroup( "Settings" );
@@ -431,9 +411,9 @@ void kSwarmSetup::slotOkPressed()
 	accept();
 }
 
-void kSwarmSetup::slotAbout()
+void kSwarmSetup::slotHelp()
 {
 	KMessageBox::information(this,
-			     i18n("Swarm\n\nCopyright (c) 1991 by Patrick J. Naughton\n\nPorted to kscreensave by Emanuel Pirker."),
+			     i18n("Swarm\n\nCopyright (c) 1991 by Patrick J. Naughton\n\nPorted to kscreensaver by Emanuel Pirker."),
 			     i18n("About Swarm"));
 }
