@@ -1,5 +1,5 @@
 /*
- *	$Id: cdeclient.cpp 409718 2005-05-05 12:52:18Z lunakl $
+ *	$Id: cdeclient.cpp 489039 2005-12-16 22:05:28Z giessl $
  *
  *	CDE KWin client - emulates the look and feel
  *	of dtwm, the CDE window manager.
@@ -716,6 +716,12 @@ void CdeClient::mouseDoubleClickEvent( QMouseEvent * e )
 	titlebarDblClickOperation();
 }
 
+void CdeClient::wheelEvent( QWheelEvent * e )
+{
+    if (isSetShade() || titleLayout->geometry().contains( e->pos() ) )
+        titlebarMouseWheelOperation( e->delta());
+}
+
 void CdeClient::mousePressEvent( QMouseEvent * e )
 {
     if ( e->button() == LeftButton && titlebar->geometry().contains( e->pos() ) )
@@ -763,6 +769,9 @@ bool CdeClient::eventFilter(QObject *o, QEvent *e)
     case QEvent::Show:
 	showEvent(static_cast< QShowEvent* >(e));
 	return true;
+    case QEvent::Wheel:
+	wheelEvent( static_cast< QWheelEvent* >( e ));
+	return true;
     default:
 	break;
     }
