@@ -1,5 +1,5 @@
 /*
- *	$Id: config.h 234652 2003-06-30 08:16:28Z aseigo $
+ *	$Id: config.h 465369 2005-09-29 14:33:08Z mueller $
  *
  *	This file contains the IceWM configuration widget
  *
@@ -19,8 +19,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; see the file COPYING.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  *
  */
 
