@@ -499,6 +499,13 @@ void StdClient::mouseDoubleClickEvent( QMouseEvent * e )
 }
 
 
+void StdClient::wheelEvent( QWheelEvent * e )
+{
+    if (isSetShade() || QRect( 0, 0, width(), titlebar->geometry().height() ).contains( e->pos() ) )
+        titlebarMouseWheelOperation( e->delta());
+}
+
+
 void StdClient::iconChange()
 {
     if (button[ButtonMenu]) {
@@ -556,6 +563,10 @@ bool StdClient::eventFilter( QObject* o, QEvent* e )
 	processMousePressEvent( static_cast< QMouseEvent* >( e ) );
 	return true;
 
+    case QEvent::Wheel:
+	wheelEvent( static_cast< QWheelEvent* >( e ));
+	return true;
+
     default:
 	return false;
     }
@@ -658,6 +669,12 @@ void StdToolClient::mouseDoubleClickEvent( QMouseEvent * e )
         titlebarDblClickOperation();
 }
 
+void StdToolClient::wheelEvent( QWheelEvent * e )
+{
+    if (isSetShade() || QRect( 0, 0, width(), titlebar->geometry().height() ).contains( e->pos() ) )
+        titlebarMouseWheelOperation( e->delta());
+}
+
 void StdToolClient::captionChange()
 {
     widget()->repaint( titlebar->geometry(), FALSE );
@@ -695,6 +712,10 @@ bool StdToolClient::eventFilter( QObject* o, QEvent* e )
 	processMousePressEvent( static_cast< QMouseEvent* >( e ) );
 	return true;
 
+    case QEvent::Wheel:
+	wheelEvent( static_cast< QWheelEvent* >( e ));
+	return true;
+
     default:
 	return false;
     }
