@@ -97,6 +97,9 @@ bool Manager::eventFilter(QObject *o, QEvent *e)
       case QEvent::MouseButtonPress:
          processMousePressEvent(static_cast<QMouseEvent*>(e));
          return true;
+      case QEvent::Wheel:
+         wheelEvent( static_cast< QWheelEvent* >( e ));
+         return true;
       case QEvent::MouseButtonRelease:
          return false;
       case QEvent::Show:
@@ -353,6 +356,12 @@ void Manager::mouseDoubleClickEvent(QMouseEvent *e)
       titlebarDblClickOperation();
 }
 
+void Manager::wheelEvent(QWheelEvent *e)
+{
+    if (isSetShade() || titleLayout_->geometry().contains(e->pos()) )
+        titlebarMouseWheelOperation( e->delta());
+}
+
 void Manager::paletteChange(const QPalette &)
 {
    resetLayout();
